@@ -108,8 +108,7 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
 */
     GeoPainter( QPaintDevice * paintDevice,
                 const ViewportParams *viewportParams,
-                MapQuality mapQuality = NormalQuality,
-                bool clip = true );
+                MapQuality mapQuality = NormalQuality );
 
                 
 /*!
@@ -118,18 +117,6 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     ~GeoPainter();
 
     
-/*!
-    \brief Automatically adjusts the painter to the current map quality.
-
-    Automatically adjusts the usage of antialiasing according to the current
-    map quality. It's considered good practice to call this method before
-    starting to draw with a painter. This avoids that objects don't get
-    painted in the wrong quality and it ensures that performance is always
-    optimal.
-*/
-    void autoMapQuality();
-
-    
 /*!
     \brief Returns the map quality.
     \return The map quality that got assigned to the painter.
@@ -226,16 +213,8 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
 */
     QRegion regionFromPoint ( const GeoDataPoint & point,
                               qreal strokeWidth = 3) const;
-    
-    
-/*!
-    \brief Draws a number of points at the given geographic positions.
-    All \a positions are stored in an array. The first \a pointCount points are
-    drawn using the painter's pen color.
-*/
-    void drawPoints ( const GeoDataCoordinates * positions, int pointCount );
 
-    
+
 /*!
     \brief Draws the given text at a given geographic position.
     The \a text is drawn starting at the given \a position using the painter's
@@ -309,41 +288,6 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
                       const QPixmap & pixmap /*, bool isGeoProjected = false */ );
 
 
-/*!
-    \brief Draws a line from the given start position to the end position.
-
-    The line is drawn using the current pen.
-    If \a isGeoProjected is true then the line is bent across the surface.
-    If \a isGeoProjected is false then a straight line in screen coordinates is
-    the result.
-
-    \see GeoDataCoordinates
-*/
-    void drawLine (  const GeoDataCoordinates & startPosition,
-                     const GeoDataCoordinates & endPosition,
-                     bool isGeoProjected = false );
-
-
-/*!
-    \brief Creates a region for a given line.
-
-    A QRegion object is created that represents the area covered by
-    GeoPainter::drawLine(). As such it can be used e.g. for input event handling
-    for objects that have been painted using
-    GeoPainter::drawLine( GeoDataLineString ).
-
-    The \a strokeWidth allows to extrude the QRegion by half the amount of
-    "stroke width" pixels. For input event handling it's always advisable to use
-    a width that is slightly bigger than the width of the painter's pen.
-
-    \see GeoDataCoordinates
-*/
-    QRegion regionFromLine ( const GeoDataCoordinates & startPosition,
-                             const GeoDataCoordinates & endPosition,
-                             bool isGeoProjected = false,
-                             qreal strokeWidth = 3 ) const;
-
-
 /*!
     \brief Draws a given line string (a "polyline").
 
@@ -485,51 +429,31 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     Unlike in QPainter::drawRoundedRect() the rounded corners are not specified
     in percentage but in pixels to provide for optimal aesthetics.
 
+    \param width Width of the rectangle in pixels
+    \param height Height of the rectangle in pixels
     \param xRnd Specifies the geometry of the rounded corners in pixels along
                 the x-axis.
     \param yRnd Specifies the geometry of the rounded corners in pixels along
                 the y-axis.
 
-    If \a isGeoProjected is true then the outline of the rectangle is drawn
-    in geographic coordinates. In this case the \a width and the \a height
-    are interpreted to be degrees.
-    If \a isGeoProjected is false then the outline of the rectangle is drawn
-    in screen coordinates. In this case the \a width and the \a height
-    are interpreted to be pixels.
-
     \see GeoDataCoordinates
 */
     void drawRoundRect ( const GeoDataCoordinates & centerPosition,
                          int width, int height,
-                         int xRnd = 25, int yRnd = 25,
-                         bool isGeoProjected = false );
+                         int xRnd = 25, int yRnd = 25 );
 
 
 
-    // Reenabling QPainter methods.
-
-    void drawText ( int x, int y, const QString & text );
-    void drawText ( const QPointF & position, const QString & text );
-    void drawText ( const QPoint & position, const QString & text );
-    void drawText(  const QRect & rectangle, int flags, const QString & text,
-                    QRect * boundingRect = 0 );
-    void drawEllipse ( int x, int y, int width, int height );
-    void drawEllipse ( const QRectF & rectangle );
-    void drawImage ( const QRect & target, const QImage & image,
-                     const QRect & source,
-                     Qt::ImageConversionFlags flags = Qt::AutoColor );
-    void drawImage ( const QRect& rect, const QImage& image );
-    void drawImage ( const QRectF& rect, const QImage& image );
-    void drawPixmap ( int x, int y, const QPixmap & pixmap );
-    void drawPixmap ( const QPointF & point, const QPixmap & pixmap );
-    void drawPixmap ( const QPoint & point, const QPixmap & pixmap );
-    void drawPoint ( int x, int y );
-    void drawPolyline( const QPolygonF & polyline );
-    void drawPolygon( const QPolygonF & polygon );
-    void drawLine ( int x1, int y1, int x2, int y2 );
-    void drawRect ( const QRectF & rectangle );
-    void drawRect ( const QRect & rectangle );
-    void drawRect ( int x, int y, int width, int height );
+    // Reenabling QPainter+ClipPainter methods.
+    using QPainter::drawText;
+    using QPainter::drawEllipse;
+    using QPainter::drawImage;
+    using QPainter::drawPixmap;
+    using QPainter::drawPoint;
+    using ClipPainter::drawPolyline;
+    using ClipPainter::drawPolygon;
+    using QPainter::drawRect;
+    using QPainter::drawRoundedRect;
 
  private:
     Q_DISABLE_COPY( GeoPainter )
