@@ -23,12 +23,16 @@ class CylindricalProjection;
 class CylindricalProjectionPrivate : public AbstractProjectionPrivate
 {
   public:
-    CylindricalProjectionPrivate( CylindricalProjection * parent );
+    explicit CylindricalProjectionPrivate( CylindricalProjection * parent );
 
     bool lineStringToPolygon( const GeoDataLineString &lineString,
                               const ViewportParams *viewport,
                               QVector<QPolygonF*> &polygons ) const;
 
+    void translatePolygons( const QVector<QPolygonF *> &polygons,
+                            QVector<QPolygonF *> &translatedPolygons,
+                            qreal xOffset ) const;
+
     void repeatPolygons( const ViewportParams *viewport,
                          QVector<QPolygonF *> &polygons ) const;
 
