@@ -13,9 +13,9 @@
 #include "GeoDataDocument.h"
 #include "GeoDataFolder.h"
 #include "GeoDataExtendedData.h"
+#include "GeoDataPlacemark.h"
 #include "MarbleMath.h"
 #include "RoutingModel.h"
-#include "RouteAnnotator.h"
 
 #include <QtCore/QTimer>
 #include <QtGui/QPainter>
@@ -70,7 +70,7 @@ public:
     static qreal distance( const GeoDataCoordinates &satellite, const GeoDataCoordinates &lineA, const GeoDataCoordinates &lineB );
 
     /**
-      * Returns the point reached when travelling the given distance from start with the given direction
+      * Returns the point reached when traveling the given distance from start with the given direction
       */
     static GeoDataCoordinates coordinates( const GeoDataCoordinates &start, qreal distance, qreal bearing );
 
@@ -356,10 +356,6 @@ void AlternativeRoutesModel::addRestrainedRoutes()
 //            GeoDataDocument* base = d->m_routes.isEmpty() ? 0 : d->m_routes.first();
             d->m_routes.push_back( route );
             endInsertRows();
-//            RouteAnnotator* task = new RouteAnnotator( d->m_marbleModel, this, route, base );
-//            connect( task, SIGNAL( finished( GeoDataDocument*) ),
-//                     this, SLOT( update(GeoDataDocument*) ) );
-//            task->run();
         }
     }
 
@@ -383,7 +379,7 @@ void AlternativeRoutesModel::addRoute( GeoDataDocument* document, WritePolicy po
         int responseTime = d->m_responseTime.elapsed();
         d->m_restrainedRoutes.push_back( document );
         int timeout = qMin<int>( 500, qMax<int>( 50,  responseTime * 2 ) );
-        QTimer::singleShot( timeout, this, SLOT( addRestrainedRoutes() ) );
+        QTimer::singleShot( timeout, this, SLOT(addRestrainedRoutes()) );
         return;
     } else if ( d->m_routes.isEmpty() && !d->m_restrainedRoutes.isEmpty() ) {
         d->m_restrainedRoutes.push_back( document );
@@ -406,11 +402,6 @@ void AlternativeRoutesModel::addRoute( GeoDataDocument* document, WritePolicy po
         beginInsertRows( QModelIndex(), affected, affected );
         d->m_routes.push_back( document );
         endInsertRows();
-
-//        RouteAnnotator* task = new RouteAnnotator( d->m_marbleModel, this, document, d->m_routes.first() );
-//        connect( task, SIGNAL( finished( GeoDataDocument*) ),
-//                 this, SLOT( update(GeoDataDocument*) ) );
-//        task->run();
     }
 }
 
@@ -449,6 +440,7 @@ void AlternativeRoutesModel::setCurrentRoute( int index )
     if ( index >= 0 && index < rowCount() && d->m_currentIndex != index ) {
         d->m_currentIndex = index;
         emit currentRouteChanged( currentRoute() );
+        emit currentRouteChanged( d->m_currentIndex );
     }
 }
 
