@@ -72,7 +72,7 @@ void BBCWeatherService::getAdditionalItems( const GeoDataLatLonAltBox& box,
 
 void BBCWeatherService::getItem( const QString &id, const MarbleModel * )
 {
-    if ( id.startsWith( "bbc" ) ) {
+    if ( id.startsWith( QLatin1String( "bbc" ) ) ) {
         BBCStation const station = m_itemGetter->station( id );
         if ( station.bbcId() > 0 ) {
             createItem( station );
@@ -87,9 +87,9 @@ void BBCWeatherService::fetchStationList()
     }
 
     connect( m_itemGetter,
-             SIGNAL( foundStation( BBCStation ) ),
+             SIGNAL(foundStation(BBCStation)),
              this,
-             SLOT( createItem( BBCStation ) ) );
+             SLOT(createItem(BBCStation)) );
 
     m_stationList = m_parser->stationList();
     m_itemGetter->setStationList( m_stationList );
@@ -101,6 +101,7 @@ void BBCWeatherService::fetchStationList()
 void BBCWeatherService::createItem( BBCStation station )
 {
     BBCWeatherItem *item = new BBCWeatherItem( this );
+    item->setMarbleWidget( marbleWidget() );
     item->setBbcId( station.bbcId() );
     item->setCoordinate( station.coordinate() );
     item->setPriority( station.priority() );
@@ -117,8 +118,8 @@ void BBCWeatherService::setupList()
 
     m_parser = new StationListParser( this );
     m_parser->setPath( MarbleDirs::path( "weather/bbc-stations.xml" ) );
-    connect( m_parser, SIGNAL( finished() ),
-             this,     SLOT( fetchStationList() ) );
+    connect( m_parser, SIGNAL(finished()),
+             this,     SLOT(fetchStationList()) );
     if ( m_parser->wait( 100 ) ) {
         m_parser->start( QThread::IdlePriority );
     }
