@@ -26,15 +26,15 @@
 
 using namespace Marble;
 
-WeatherModel::WeatherModel( const PluginManager *pluginManager, QObject *parent )
-    : AbstractDataPluginModel( "weather", pluginManager, parent ),
+WeatherModel::WeatherModel( const MarbleModel *marbleModel, QObject *parent )
+    : AbstractDataPluginModel( "weather", marbleModel, parent ),
       m_initialized( false )
 {
     registerItemProperties( WeatherItem::staticMetaObject );
     createServices();
 
     m_timer = new QTimer();
-    connect( m_timer, SIGNAL( timeout() ), SLOT( updateItems() ) );
+    connect( m_timer, SIGNAL(timeout()), SLOT(updateItems()) );
 
     // Default interval = 3 hours
     setUpdateInterval( 3 );
@@ -91,22 +91,20 @@ void WeatherModel::downloadItemData( const QUrl& url,
 }
 
 void WeatherModel::getAdditionalItems( const GeoDataLatLonAltBox& box,
-                               const MarbleModel *model,
                                qint32 number )
 {
     m_lastBox = box;
-    m_lastModel = model;
     m_lastNumber = number;
 
     m_initialized = true;
 
-    emit additionalItemsRequested( box, model, number );
+    emit additionalItemsRequested( box, marbleModel(), number );
 }
 
-void WeatherModel::getItem( const QString &id, const MarbleModel *model )
+void WeatherModel::getItem( const QString &id )
 {
     foreach( AbstractWeatherService* service, m_services ) {
-        service->getItem( id, model );
+        service->getItem( id, marbleModel() );
     }
 }
 
@@ -118,7 +116,7 @@ void WeatherModel::parseFile( const QByteArray& file )
 void WeatherModel::updateItems()
 {
     clear();
-    emit additionalItemsRequested( m_lastBox, m_lastModel, m_lastNumber );
+    emit additionalItemsRequested( m_lastBox, marbleModel(), m_lastNumber );
     emit itemsUpdated();
 }
 
@@ -134,29 +132,36 @@ void WeatherModel::downloadDescriptionFileRequested( const QUrl& url )
     downloadDescriptionFile( url );
 }
 
+void WeatherModel::setMarbleWidget(MarbleWidget *widget)
+{
+    foreach ( AbstractWeatherService* service, m_services ) {
+        service->setMarbleWidget( widget );
+    }
+}
+
 void WeatherModel::addService( AbstractWeatherService *service )
 {
     service->setFavoriteItems( favoriteItems() );
 
-    connect( service, SIGNAL( createdItems( QList<AbstractDataPluginItem*> ) ),
-             this, SLOT( addItemsToList( QList<AbstractDataPluginItem*> ) ) );
-    connect( service, SIGNAL( requestedDownload( const QUrl&,
-                                                 const QString&, 
-                                                 AbstractDataPluginItem * ) ),
-             this, SLOT( downloadItemData( const QUrl&,
-                                           const QString&,
-                                           AbstractDataPluginItem * ) ) );
-    connect( service, SIGNAL( downloadDescriptionFileRequested( const QUrl& ) ),
-             this, SLOT( downloadDescriptionFileRequested( const QUrl& ) ) );
+    connect( service, SIGNAL(createdItems(QList<AbstractDataPluginItem*>)),
+             this, SLOT(addItemsToList(QList<AbstractDataPluginItem*>)) );
+    connect( service, SIGNAL(requestedDownload(QUrl,
+                                               QString, 
+                                               AbstractDataPluginItem*)),
+             this, SLOT(downloadItemData(QUrl,
+                                         QString,
+                                         AbstractDataPluginItem*)) );
+    connect( service, SIGNAL(downloadDescriptionFileRequested(QUrl)),
+             this, SLOT(downloadDescriptionFileRequested(QUrl)) );
 
-    connect( this, SIGNAL( additionalItemsRequested( const GeoDataLatLonAltBox &,
-                                                     const MarbleModel *,
-                                                     qint32 ) ),
-             service, SLOT( getAdditionalItems( const GeoDataLatLonAltBox&,
-                                                const MarbleModel *,
-                                                qint32 ) ) );
-    connect( this, SIGNAL( parseFileRequested( const QByteArray& ) ),
-             service, SLOT( parseFile( const QByteArray& ) ) );
+    connect( this, SIGNAL(additionalItemsRequested(const GeoDataLatLonAltBox,
+                                                   const MarbleModel*,
+                                                   qint32)),
+             service, SLOT(getAdditionalItems(const GeoDataLatLonAltBox,
+                                              const MarbleModel*,
+                                              qint32)) );
+    connect( this, SIGNAL(parseFileRequested(QByteArray)),
+             service, SLOT(parseFile(QByteArray)) );
 
     m_services.append( service );
 }
