@@ -19,8 +19,7 @@
 #include "PluginManager.h"
 #include "GeoDataPlacemark.h"
 #include "routing/RouteRequest.h"
-
-#define addRow() QTest::newRow( QString("line %1").arg( __LINE__ ).toAscii().data() )
+#include "TestUtils.h"
 
 Q_DECLARE_METATYPE( QList<Marble::GeoDataCoordinates> )
 
@@ -34,8 +33,8 @@ class MarbleRunnerManagerTest : public QObject
 private slots:
     void initTestCase();// will be called before the first testfunction is executed.
     void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init(){};// will be called before each testfunction is executed.
-    void cleanup(){};// will be called after every testfunction.
+    void init(){ qDebug() << "start: " << t.elapsed();}// will be called before each testfunction is executed.
+    void cleanup(){ qDebug() << "end: " << t.elapsed();}// will be called after every testfunction.
 
     void testSyncPlacemarks();
 
@@ -65,11 +64,12 @@ public:
     GeoDataCoordinates m_coords;
     GeoDataCoordinates m_coords2;
     RouteRequest m_request;
+    QTime t;
 };
 
 void MarbleRunnerManagerTest::initTestCase()
 {
-    // MarbleDebug::enable = true;
+     MarbleDebug::enable = true;
     MarbleDirs::setMarbleDataPath( DATA_PATH );
     MarbleDirs::setMarblePluginPath( PLUGIN_PATH );
     m_time = 30000;
@@ -85,6 +85,7 @@ void MarbleRunnerManagerTest::initTestCase()
 
     m_request.append( m_coords );
     m_request.append( m_coords2 );
+    t.start();
 }
 
 void MarbleRunnerManagerTest::cleanupTestCase()
@@ -135,12 +136,12 @@ void MarbleRunnerManagerTest::testAsyncPlacemarks()
 {
     MarbleRunnerManager m_runnerManager(&m_pluginManager, this);
 
-    QSignalSpy finishSpy( &m_runnerManager, SIGNAL( searchFinished( QString ) ) );
-    QSignalSpy resultSpy( &m_runnerManager, SIGNAL( searchResultChanged( QVector<GeoDataPlacemark*> ) ) );
+    QSignalSpy finishSpy( &m_runnerManager, SIGNAL(searchFinished(QString)) );
+    QSignalSpy resultSpy( &m_runnerManager, SIGNAL(searchResultChanged(QVector<GeoDataPlacemark*>)) );
 
     QEventLoop loop;
-    connect( &m_runnerManager, SIGNAL( searchFinished( QString ) ),
-             &loop, SLOT( quit() ), Qt::QueuedConnection );
+    connect( &m_runnerManager, SIGNAL(searchFinished(QString)),
+             &loop, SLOT(quit()), Qt::QueuedConnection );
 
     QFETCH( QString, name );
     m_runnerManager.findPlacemarks( name );
@@ -199,8 +200,8 @@ void MarbleRunnerManagerTest::testAsyncReverse()
     QSignalSpy resultSpy( &m_runnerManager, SIGNAL(reverseGeocodingFinished(GeoDataCoordinates,GeoDataPlacemark)) );
 
     QEventLoop loop;
-    connect( &m_runnerManager, SIGNAL( reverseGeocodingFinished() ),
-             &loop, SLOT( quit() ), Qt::QueuedConnection );
+    connect( &m_runnerManager, SIGNAL(reverseGeocodingFinished()),
+             &loop, SLOT(quit()), Qt::QueuedConnection );
 
     QFETCH( GeoDataCoordinates, coordinates );
     m_runnerManager.reverseGeocoding( coordinates );
@@ -218,7 +219,7 @@ void MarbleRunnerManagerTest::testSyncRouting()
     MarbleRunnerManager m_runnerManager(&m_pluginManager, this);
 
     QSignalSpy finishSpy( &m_runnerManager, SIGNAL(routingFinished()) );
-    QSignalSpy resultSpy( &m_runnerManager, SIGNAL( routeRetrieved(GeoDataDocument*)) );
+    QSignalSpy resultSpy( &m_runnerManager, SIGNAL(routeRetrieved(GeoDataDocument*)) );
 
     QCOMPARE( finishSpy.count(), 0 );
     QCOMPARE( resultSpy.count(), 0 );
@@ -245,11 +246,11 @@ void MarbleRunnerManagerTest::testAsyncRouting()
     MarbleRunnerManager m_runnerManager(&m_pluginManager, this);
 
     QSignalSpy finishSpy( &m_runnerManager, SIGNAL(routingFinished()) );
-    QSignalSpy resultSpy( &m_runnerManager, SIGNAL( routeRetrieved(GeoDataDocument*)) );
+    QSignalSpy resultSpy( &m_runnerManager, SIGNAL(routeRetrieved(GeoDataDocument*)) );
 
     QEventLoop loop;
-    connect( &m_runnerManager, SIGNAL( routingFinished() ),
-             &loop, SLOT( quit() ), Qt::QueuedConnection );
+    connect( &m_runnerManager, SIGNAL(routingFinished()),
+             &loop, SLOT(quit()), Qt::QueuedConnection );
 
     QFETCH( QList<GeoDataCoordinates>, coordinatesList );
     RouteRequest request;
@@ -272,11 +273,9 @@ void MarbleRunnerManagerTest::testSyncParsing_data()
     QTest::addColumn<QString>( "fileName" );
     QTest::addColumn<int>( "resultCount" );
 
-    addRow() << MarbleDirs::path( "placemarks/otherplacemarks.cache" ) << 1;
 
     addRow() << MarbleDirs::path( "mwdbii/DATELINE.PNT" )    << 1;
     addRow() << MarbleDirs::path( "mwdbii/PCOAST.PNT" )      << 1;
-    addRow() << MarbleDirs::path( "mwdbii/PGLACIER.PNT" )    << 1;
     addRow() << MarbleDirs::path( "mwdbii/PLAKEISLAND.PNT" ) << 1;
     addRow() << MarbleDirs::path( "mwdbii/PDIFFBORDER.PNT" ) << 1;
     addRow() << MarbleDirs::path( "mwdbii/PISLAND.PNT" )     << 1;
@@ -284,15 +283,25 @@ void MarbleRunnerManagerTest::testSyncParsing_data()
     addRow() << MarbleDirs::path( "mwdbii/PUSA48.DIFF.PNT" ) << 1;
     addRow() << MarbleDirs::path( "mwdbii/RIVER.PNT" )       << 1;
 
-    addRow() << MarbleDirs::path( "flags/flag_tv.svg" ) << 0;
+    addNamedRow("cache") << QString( MARBLE_SRC_DIR ).append( "/data/placemarks/otherplacemarks.cache" ) << 1;
+    addNamedRow("gpx") << QString( MARBLE_SRC_DIR ).append( "/examples/gpx/mjolby.gpx") << 1;
+    //json
+    addNamedRow("kml") << QString( MARBLE_SRC_DIR ).append( "/examples/kml/NewYork.kml") << 1;
+    //log
+    addNamedRow("osm") << QString( MARBLE_SRC_DIR ).append( "/examples/osm/map.osm") << 1;
+    addNamedRow("pn2") << QString( MARBLE_SRC_DIR ).append( "/data/naturalearth/50m_lakes.pn2") << 1;
+    addNamedRow("pnt") << QString( MARBLE_SRC_DIR ).append( "/data/mwdbii/PGLACIER.PNT" )    << 1;
+    //shp
+
+    addNamedRow("svg") << MarbleDirs::path( "flags/flag_tv.svg" ) << 0;
 }
 
 void MarbleRunnerManagerTest::testSyncParsing()
 {
     MarbleRunnerManager m_runnerManager(&m_pluginManager, this);
 
-    QSignalSpy finishSpy( &m_runnerManager, SIGNAL( parsingFinished()) );
-    QSignalSpy resultSpy( &m_runnerManager, SIGNAL( parsingFinished(GeoDataDocument*,QString)) );
+    QSignalSpy finishSpy( &m_runnerManager, SIGNAL(parsingFinished()) );
+    QSignalSpy resultSpy( &m_runnerManager, SIGNAL(parsingFinished(GeoDataDocument*,QString)) );
 
     QFETCH( QString, fileName );
     QFETCH( int, resultCount );
@@ -328,12 +337,12 @@ void MarbleRunnerManagerTest::testAsyncParsing()
 {
     MarbleRunnerManager m_runnerManager(&m_pluginManager, this);
 
-    QSignalSpy finishSpy( &m_runnerManager, SIGNAL( parsingFinished() ) );
-    QSignalSpy resultSpy( &m_runnerManager, SIGNAL( parsingFinished(GeoDataDocument*,QString)) );
+    QSignalSpy finishSpy( &m_runnerManager, SIGNAL(parsingFinished()) );
+    QSignalSpy resultSpy( &m_runnerManager, SIGNAL(parsingFinished(GeoDataDocument*,QString)) );
 
     QEventLoop loop;
-    connect( &m_runnerManager, SIGNAL( parsingFinished() ),
-             &loop, SLOT( quit() ), Qt::QueuedConnection );
+    connect( &m_runnerManager, SIGNAL(parsingFinished()),
+             &loop, SLOT(quit()), Qt::QueuedConnection );
 
     QFETCH( QString, fileName );
     QFETCH( int, resultCount );
